=================
Django-Assessment
=================

.. image:: https://travis-ci.org/vandorjw/django-assessment.svg?branch=master
    :target: https://travis-ci.org/vandorjw/django-assessment
    :alt: TravisCI Status
.. image:: https://coveralls.io/repos/github/vandorjw/django-assessment/badge.svg?branch=master
    :target: https://coveralls.io/github/vandorjw/django-assessment?branch=master
    :alt: Coveralls Status
.. image:: https://sonarcloud.io/api/badges/gate?key=vandorjw.django-assessment
    :target: https://sonarcloud.io/dashboard?id=vandorjw.django-assessment
    :alt: Sonarcloud Status
.. image:: https://requires.io/github/vandorjw/django-assessment/requirements.svg?branch=master
    :target: https://requires.io/github/vandorjw/django-assessment/requirements/?branch=master
    :alt: Requirements Status

Simple appllication for managing a survey/quiz within your Django Web Site.

Installing the package
======================
Using pip::

    $ not-yet-available

Features
========
* RESTful API

Online resources
================
* `Code repository <https://github.com/vandorjw/django-assessment>`_
* Documentation
* `Travis CI server <https://travis-ci.org/vandorjw/django-assessment>`_
